import { ErrorTypeEnum, EventActionType, actionResult, actionResultError } from 'quidproquo-core';
import { GLOBAL_WEBSOCKET_API_NAME } from './types';
import { WebSocketEventType, qpqWebServerUtils } from 'quidproquo-webserver';
const getProcessMatchStory = (qpqConfig) => {
    const userDirectoryConfig = qpqWebServerUtils.getWebsocketEntryByApiName(GLOBAL_WEBSOCKET_API_NAME, qpqConfig);
    return async ({ qpqEventRecord }) => {
        switch (qpqEventRecord.eventType) {
            case WebSocketEventType.Connect:
                return actionResult({
                    src: userDirectoryConfig.eventProcessors.onConnect.src,
                    runtime: userDirectoryConfig.eventProcessors.onConnect.runtime,
                });
            case WebSocketEventType.Disconnect:
                return actionResult({
                    src: userDirectoryConfig.eventProcessors.onDisconnect.src,
                    runtime: userDirectoryConfig.eventProcessors.onDisconnect.runtime,
                });
            case WebSocketEventType.Message:
                return actionResult({
                    src: userDirectoryConfig.eventProcessors.onMessage.src,
                    runtime: userDirectoryConfig.eventProcessors.onMessage.runtime,
                });
            default:
                return actionResultError(ErrorTypeEnum.NotFound, `Websocket lambda not implemented for ${qpqEventRecord.eventType}`);
        }
    };
};
export default (qpqConfig) => {
    return {
        [EventActionType.MatchStory]: getProcessMatchStory(qpqConfig),
    };
};
