import { actionResult, qpqCoreUtils } from 'quidproquo-core';
import { AdminActionType, } from 'quidproquo-webserver';
import { getQpqRuntimeResourceNameFromConfig } from '../../../awsNamingUtils';
import { getPagedItemsOverRange } from '../../../logic/dynamo/getPagedItemsOverRange';
import { getLogChildrenByFromCorrelation } from '../../../logic/dynamo/getLogChildrenByFromCorrelation';
import { getLogByCorrelation } from '../../../logic/dynamo/getLogByCorrelation';
import { readTextFile } from '../../../logic/s3/readTextFile';
// TODO: Centralize this
const QPQ_LOG_BUCKET_NAME = 'logs';
const getAdminGetLogsActionProcessor = (qpqConfig) => {
    return async ({ runtimeType, nextPageKey, startIsoDateTime, endIsoDateTime }) => {
        const tableName = getQpqRuntimeResourceNameFromConfig(QPQ_LOG_BUCKET_NAME, qpqConfig, 'log');
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const response = await getPagedItemsOverRange(tableName, region, runtimeType, startIsoDateTime, endIsoDateTime, nextPageKey);
        return actionResult(response);
    };
};
const getLogMetadataChildrenActionProcessor = (qpqConfig) => {
    return async ({ correlationId }) => {
        const tableName = getQpqRuntimeResourceNameFromConfig(QPQ_LOG_BUCKET_NAME, qpqConfig, 'flog');
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const response = await getLogChildrenByFromCorrelation(tableName, region, correlationId);
        return actionResult(response);
    };
};
const getLogMetadataActionProcessor = (qpqConfig) => {
    return async ({ correlationId }) => {
        const tableName = getQpqRuntimeResourceNameFromConfig(QPQ_LOG_BUCKET_NAME, qpqConfig, 'log');
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const response = await getLogByCorrelation(tableName, region, correlationId);
        return actionResult(response);
    };
};
const getAdminGetLogActionProcessor = (qpqConfig) => {
    return async ({ correlationId }) => {
        const bucketName = getQpqRuntimeResourceNameFromConfig(QPQ_LOG_BUCKET_NAME, qpqConfig, 'log');
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const logJson = await readTextFile(bucketName, `${correlationId}.json`, region);
        const response = JSON.parse(logJson);
        return actionResult(response);
    };
};
export default (qpqConfig) => {
    return {
        [AdminActionType.GetLogs]: getAdminGetLogsActionProcessor(qpqConfig),
        [AdminActionType.GetLog]: getAdminGetLogActionProcessor(qpqConfig),
        [AdminActionType.GetLogMetadataChildren]: getLogMetadataChildrenActionProcessor(qpqConfig),
        [AdminActionType.GetLogMetadata]: getLogMetadataActionProcessor(qpqConfig),
    };
};
